#include <sys/inotify.h>
#include <inotifytools/inotifytools.h>
#include <cerrno>
#include <poll.h>
#include "project.h"

#define MAX_WDS 16

typedef void (Project::*ProjectReloadFn)();

class NotifyService {
public:
	NotifyService() {
		if (!inotifytools_initialize()) {
			fprintf(stderr, "inotifytools init error: %s\n", strerror(inotifytools_error()));
			exit(EXIT_FAILURE);
		}
	}

	void watch(Project &project) {
		inotifytools_watch_recursively(project.basepath.str().c_str(),
				IN_MODIFY | IN_MOVED_TO);
	}

	void _poll() {
		struct inotify_event *event = inotifytools_next_event(0);

		if (inotifytools_error() == EINTR)
			return;

		if (inotifytools_error() != 0) {
			fprintf(stderr, "inotifytools event error: %s\n", strerror(inotifytools_error()));
			exit(EXIT_FAILURE);
		}


		if (event != NULL) {
			std::cout << "new inotify event! file: " << event->name << '\n';
			std::cout << "filename: " << inotifytools_filename_from_wd(event->wd) << '\n';
		}
	}
private:
};
